# oneNeuron.pypi
oneNeuron.pypi


## how to use

```python
from oneNeuron.perceptron import Perceptron

## get X and y and then use below commands

model = Perceptron(eta=eta, epochs=epochs)
model.fit(X, y)

```

# reference -
[official python doc]  (https://packaging.python.org/tutorials/packaging-projects/)

[official docs for github action] (https://docs.github.com/en/actions/automating-builds-and-tests/building-and-testing-python#publishing-to-package-registries)